pub enum GradientKind {
Linear {
start: Point,
end: Point,
},
Radial {
start_center: Point,
start_radius: f32,
end_center: Point,
end_radius: f32,
},
Sweep {
center: Point,
start_angle: f32,
end_angle: f32,
},
}Expand description
Properties for the supported gradient types.
Variants
Linear
Gradient that transitions between two or more colors along a line.
Radial
Gradient that transitions between two or more colors that radiate from an origin.
Fields
Sweep
Gradient that transitions between two or more colors that rotate around a center point.