pub struct ColorStop {
pub offset: f32,
pub color: Color,
}Expand description
Offset and color of a transition point in a gradient.
Fields
offset: f32Normalized offset of the stop.
color: ColorColor at the specified offset.
Implementations
Sourceimpl ColorStop
impl ColorStop
Sourcepub fn with_alpha_factor(self, alpha: f32) -> ColorStop
👎Deprecated since 0.2.0: This method has been renamed to multiply_alpha.
pub fn with_alpha_factor(self, alpha: f32) -> ColorStop
This method has been renamed to multiply_alpha.
Returns the color stop with the alpha component multiplied by the specified factor.
Sourcepub fn multiply_alpha(self, alpha: f32) -> ColorStop
pub fn multiply_alpha(self, alpha: f32) -> ColorStop
Returns the color stop with the alpha component multiplied by alpha.
The behaviour of this transformation is undefined if alpha is negative.
If any resulting alphas would overflow, these currently saturate (to opaque).