pub struct Gradient {
pub kind: GradientKind,
pub extend: Extend,
pub stops: SmallVec<[ColorStop; 4]>,
}Expand description
Definition of a gradient that transitions between two or more colors.
Fields
kind: GradientKindKind and properties of the gradient.
extend: ExtendExtend mode.
stops: SmallVec<[ColorStop; 4]>Color stop collection.
Implementations
Sourceimpl Gradient
impl Gradient
Sourcepub fn new_linear(start: impl Into<Point>, end: impl Into<Point>) -> Gradient
pub fn new_linear(start: impl Into<Point>, end: impl Into<Point>) -> Gradient
Creates a new linear gradient for the specified start and end points.
Sourcepub fn new_radial(center: impl Into<Point>, radius: f32) -> Gradient
pub fn new_radial(center: impl Into<Point>, radius: f32) -> Gradient
Creates a new radial gradient for the specified center point and radius.
Sourcepub fn new_two_point_radial(
start_center: impl Into<Point>,
start_radius: f32,
end_center: impl Into<Point>,
end_radius: f32,
) -> Gradient
pub fn new_two_point_radial( start_center: impl Into<Point>, start_radius: f32, end_center: impl Into<Point>, end_radius: f32, ) -> Gradient
Creates a new two point radial gradient for the specified center points and radii.
Sourcepub fn new_sweep(
center: impl Into<Point>,
start_angle: f32,
end_angle: f32,
) -> Gradient
pub fn new_sweep( center: impl Into<Point>, start_angle: f32, end_angle: f32, ) -> Gradient
Creates a new sweep gradient for the specified center point, start and end angles.
Sourcepub fn with_extend(self, mode: Extend) -> Gradient
pub fn with_extend(self, mode: Extend) -> Gradient
Builder method for setting the gradient extend mode.
Sourcepub fn with_stops(self, stops: impl ColorStopsSource) -> Gradient
pub fn with_stops(self, stops: impl ColorStopsSource) -> Gradient
Builder method for setting the color stop collection.