pub trait ProjectRuntimeExt {
// Required methods
fn show(self) -> Result<()>;
fn export(&mut self) -> Result<()>;
}Expand description
Extension trait to provide ergonomic runtime methods to Project.
This trait keeps the core Project struct free of side-effects while
allowing for a simple .show() or .export() API.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".